# coding=utf-8
# Stubs for six (Python 3.5)
from __future__ import print_function, absolute_import, unicode_literals

from nf.csdk.c_sdk import py_nfi_strategy_duidao, py_nfi_strategy_budan, py_nfi_update_strategy_datas, \
    py_nfi_add_strategy_rds, py_nfi_strategy_kongpan
from nf.pb.strategy.strategy_params.strategy.params_pb2 import StrategyDuidaoParams, StrategyBudanParams, \
    StrategyLapanParams
from nf.pb.trade.api.trade.service_pb2 import UpdateStrategyDatasReq, AddStrategyRdsReq


def run_strategy_duidao(**kwargs):
    params = StrategyDuidaoParams()
    for key in kwargs:
        setattr(params, key, kwargs[key])

    req = params.SerializeToString()

    return py_nfi_strategy_duidao(req)


def run_strategy_budan(**kwargs):
    params = StrategyBudanParams()
    for key in kwargs:
        setattr(params, key, kwargs[key])

    req = params.SerializeToString()

    return py_nfi_strategy_budan(req)


def update_strategy_datas(vol_sum=0.0, runtime_sum=0):
    if isinstance(vol_sum, float):
        vol_sum = '%.2f' % vol_sum

    if not isinstance(vol_sum, str):
        vol_sum = str(vol_sum)

    if not isinstance(runtime_sum, str):
        runtime_sum = str(runtime_sum)

    req = UpdateStrategyDatasReq()
    req.vol_sum = vol_sum
    req.runtime_sum = runtime_sum

    sreq = req.SerializeToString()

    return py_nfi_update_strategy_datas(sreq)

def add_strategy_rds(type_name, rds_value=0.0, rds_info=''):

    if type_name is None or not isinstance(type_name, str):
        raise TypeError('add_strategy_rds() : argument missing or incorrect argument type.')

    if not isinstance(rds_value, float) and not isinstance(rds_value, int):
        raise TypeError('add_strategy_rds() : argument missing or incorrect argument type.')
        return

    if not isinstance(rds_info, str):
        raise TypeError('add_strategy_rds() : argument missing or incorrect argument type.')

    req = AddStrategyRdsReq()
    req.type_name = type_name
    req.rds_value = rds_value
    req.rds_info = rds_info

    sreq = req.SerializeToString()

    return py_nfi_add_strategy_rds(sreq)


def run_strategy_kongpan(**kwargs):
    params = StrategyLapanParams()
    for key in kwargs:
        setattr(params, key, kwargs[key])

    req = params.SerializeToString()

    return py_nfi_strategy_kongpan(req)




# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth.service.proto',
  package='auth.api',
  syntax='proto3',
  serialized_pb=_b('\n\x12\x61uth.service.proto\x12\x08\x61uth.api\x1a\x1cgoogle/api/annotations.proto\"4\n\x0eVerifyTokenReq\x12\r\n\x05token\x18\x02 \x01(\t\x12\x13\n\x0b\x63lient_type\x18\x03 \x01(\t\"@\n\x0eVerifyTokenRsp\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\"\n\x07profile\x18\x02 \x01(\x0b\x32\x11.auth.api.Profile\"\x92\x01\n\x07Profile\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x35\n\nproperties\x18\x03 \x03(\x0b\x32!.auth.api.Profile.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32r\n\x0b\x41uthService\x12\x63\n\x0bVerifyToken\x12\x18.auth.api.VerifyTokenReq\x1a\x18.auth.api.VerifyTokenRsp\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/auth/token/verify:\x01*B/Z-nextfin.com/nfplatform/core/api/auth;auth_apib\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_VERIFYTOKENREQ = _descriptor.Descriptor(
  name='VerifyTokenReq',
  full_name='auth.api.VerifyTokenReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth.api.VerifyTokenReq.token', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_type', full_name='auth.api.VerifyTokenReq.client_type', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=114,
)


_VERIFYTOKENRSP = _descriptor.Descriptor(
  name='VerifyTokenRsp',
  full_name='auth.api.VerifyTokenRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='auth.api.VerifyTokenRsp.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profile', full_name='auth.api.VerifyTokenRsp.profile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=180,
)


_PROFILE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='auth.api.Profile.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth.api.Profile.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth.api.Profile.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=329,
)

_PROFILE = _descriptor.Descriptor(
  name='Profile',
  full_name='auth.api.Profile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='auth.api.Profile.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='auth.api.Profile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='auth.api.Profile.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PROFILE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=329,
)

_VERIFYTOKENRSP.fields_by_name['profile'].message_type = _PROFILE
_PROFILE_PROPERTIESENTRY.containing_type = _PROFILE
_PROFILE.fields_by_name['properties'].message_type = _PROFILE_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['VerifyTokenReq'] = _VERIFYTOKENREQ
DESCRIPTOR.message_types_by_name['VerifyTokenRsp'] = _VERIFYTOKENRSP
DESCRIPTOR.message_types_by_name['Profile'] = _PROFILE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VerifyTokenReq = _reflection.GeneratedProtocolMessageType('VerifyTokenReq', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYTOKENREQ,
  __module__ = 'auth.service_pb2'
  # @@protoc_insertion_point(class_scope:auth.api.VerifyTokenReq)
  ))
_sym_db.RegisterMessage(VerifyTokenReq)

VerifyTokenRsp = _reflection.GeneratedProtocolMessageType('VerifyTokenRsp', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYTOKENRSP,
  __module__ = 'auth.service_pb2'
  # @@protoc_insertion_point(class_scope:auth.api.VerifyTokenRsp)
  ))
_sym_db.RegisterMessage(VerifyTokenRsp)

Profile = _reflection.GeneratedProtocolMessageType('Profile', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PROFILE_PROPERTIESENTRY,
    __module__ = 'auth.service_pb2'
    # @@protoc_insertion_point(class_scope:auth.api.Profile.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _PROFILE,
  __module__ = 'auth.service_pb2'
  # @@protoc_insertion_point(class_scope:auth.api.Profile)
  ))
_sym_db.RegisterMessage(Profile)
_sym_db.RegisterMessage(Profile.PropertiesEntry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z-nextfin.com/nfplatform/core/api/auth;auth_api'))
_PROFILE_PROPERTIESENTRY.has_options = True
_PROFILE_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))

_AUTHSERVICE = _descriptor.ServiceDescriptor(
  name='AuthService',
  full_name='auth.api.AuthService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=331,
  serialized_end=445,
  methods=[
  _descriptor.MethodDescriptor(
    name='VerifyToken',
    full_name='auth.api.AuthService.VerifyToken',
    index=0,
    containing_service=None,
    input_type=_VERIFYTOKENREQ,
    output_type=_VERIFYTOKENRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/v1/auth/token/verify:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHSERVICE)

DESCRIPTOR.services_by_name['AuthService'] = _AUTHSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nf.pb.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core/api/common.proto',
  package='core.api',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x63ore/api/common.proto\x12\x08\x63ore.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"2\n\x08Property\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03val\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x87\x01\n\x06\x46ilter\x12\x0e\n\x06\x66ields\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0c\n\x04sort\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x10\n\x08pagesize\x18\x06 \x01(\x05\x12\x10\n\x08\x66romdate\x18\x07 \x01(\t\x12\x0e\n\x06todate\x18\x08 \x01(\t\"1\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04info\x18\x03 \x01(\t\"\x8d\x01\n\x11\x43onnectionAddress\x12\r\n\x05title\x18\x01 \x01(\t\x12\x39\n\x07\x61\x64\x64ress\x18\x02 \x03(\x0b\x32(.core.api.ConnectionAddress.AddressEntry\x1a.\n\x0c\x41\x64\x64ressEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x01\n\x10\x43onnectionStatus\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x1e\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0f.core.api.Error\"\xb0\x01\n\x05State\x12\x11\n\rState_UNKNOWN\x10\x00\x12\x14\n\x10State_CONNECTING\x10\x01\x12\x13\n\x0fState_CONNECTED\x10\x02\x12\x12\n\x0eState_LOGGEDIN\x10\x03\x12\x17\n\x13State_DISCONNECTING\x10\x04\x12\x16\n\x12State_DISCONNECTED\x10\x05\x12\x0f\n\x0bState_ERROR\x10\x06\x12\x13\n\x0fState_LOGGEDOUT\x10\x07\"\x8b\x01\n\x03Log\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x10\n\x08owner_id\x18\x04 \x01(\t\x12\x46\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\"#\n\x04Logs\x12\x1b\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\r.core.api.Log\"A\n\tHeartbeat\x12\x34\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"\xa6\x03\n\nSymbolInfo\x12\x0f\n\x07symbole\x18\x01 \x01(\t\x12\x0f\n\x07marcket\x18\x02 \x01(\t\x12\r\n\x05\x66ront\x18\x03 \x01(\t\x12\x0c\n\x04rear\x18\x04 \x01(\t\x12\x17\n\x0fprice_precision\x18\x05 \x01(\x05\x12\x18\n\x10\x61mount_precision\x18\x06 \x01(\x05\x12\x17\n\x0f\x63ontract_period\x18\x07 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x08 \x01(\t\x12\r\n\x05quote\x18\t \x01(\t\x12\x36\n\x0clisting_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x35\n\x0bsettle_date\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x14\n\x0cmax_leverage\x18\x0c \x01(\x01\x12\x0f\n\x07min_pos\x18\r \x01(\x05\x12\x13\n\x0bquote_value\x18\x0e \x01(\x01\x12\x15\n\rsettlCurrency\x18\x0f \x01(\t\x12\x19\n\x11position_currency\x18\x10 \x01(\t\x12\x13\n\x0bmarket_name\x18\x11 \x01(\t\"4\n\x0e\x43ommSymbolInfo\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.core.api.SymbolInfo\"5\n\x0f\x43ommSymbolInfos\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.core.api.SymbolInfo\"\xa2\x01\n\x10StrategyTemplate\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x13\n\x0bsort_weight\x18\x05 \x01(\x05\x12\x12\n\nparam_info\x18\x06 \x01(\t\x12\x12\n\nparam_mode\x18\x07 \x01(\x05\x12\x10\n\x08stg_type\x18\x08 \x01(\x05\"@\n\x14StrategyTemplateItem\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1a.core.api.StrategyTemplate\"A\n\x15StrategyTemplateItems\x12(\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1a.core.api.StrategyTemplateB*Z(nextfin.com/nfplatform/core/api;core_apib\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])



_CONNECTIONSTATUS_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='core.api.ConnectionStatus.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='State_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_CONNECTING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_CONNECTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_LOGGEDIN', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_DISCONNECTING', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_DISCONNECTED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_ERROR', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_LOGGEDOUT', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=544,
  serialized_end=720,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONSTATUS_STATE)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='core.api.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.Property.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val', full_name='core.api.Property.val', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='core.api.Property.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=140,
)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='core.api.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='core.api.Filter.fields', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='core.api.Filter.filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort', full_name='core.api.Filter.sort', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='core.api.Filter.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='page', full_name='core.api.Filter.page', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagesize', full_name='core.api.Filter.pagesize', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fromdate', full_name='core.api.Filter.fromdate', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todate', full_name='core.api.Filter.todate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=278,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='core.api.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='core.api.Error.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='core.api.Error.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='info', full_name='core.api.Error.info', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=329,
)


_CONNECTIONADDRESS_ADDRESSENTRY = _descriptor.Descriptor(
  name='AddressEntry',
  full_name='core.api.ConnectionAddress.AddressEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.ConnectionAddress.AddressEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.ConnectionAddress.AddressEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=473,
)

_CONNECTIONADDRESS = _descriptor.Descriptor(
  name='ConnectionAddress',
  full_name='core.api.ConnectionAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='core.api.ConnectionAddress.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='address', full_name='core.api.ConnectionAddress.address', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTIONADDRESS_ADDRESSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=473,
)


_CONNECTIONSTATUS = _descriptor.Descriptor(
  name='ConnectionStatus',
  full_name='core.api.ConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='core.api.ConnectionStatus.state', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='core.api.ConnectionStatus.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONSTATUS_STATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=720,
)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='core.api.Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='core.api.Log.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='core.api.Log.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg', full_name='core.api.Log.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='core.api.Log.owner_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Log.created_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=862,
)


_LOGS = _descriptor.Descriptor(
  name='Logs',
  full_name='core.api.Logs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Logs.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=899,
)


_HEARTBEAT = _descriptor.Descriptor(
  name='Heartbeat',
  full_name='core.api.Heartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Heartbeat.created_at', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=901,
  serialized_end=966,
)


_SYMBOLINFO = _descriptor.Descriptor(
  name='SymbolInfo',
  full_name='core.api.SymbolInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbole', full_name='core.api.SymbolInfo.symbole', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='marcket', full_name='core.api.SymbolInfo.marcket', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='core.api.SymbolInfo.front', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='core.api.SymbolInfo.rear', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_precision', full_name='core.api.SymbolInfo.price_precision', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount_precision', full_name='core.api.SymbolInfo.amount_precision', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contract_period', full_name='core.api.SymbolInfo.contract_period', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base', full_name='core.api.SymbolInfo.base', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote', full_name='core.api.SymbolInfo.quote', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listing_date', full_name='core.api.SymbolInfo.listing_date', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='settle_date', full_name='core.api.SymbolInfo.settle_date', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='max_leverage', full_name='core.api.SymbolInfo.max_leverage', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_pos', full_name='core.api.SymbolInfo.min_pos', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote_value', full_name='core.api.SymbolInfo.quote_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settlCurrency', full_name='core.api.SymbolInfo.settlCurrency', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_currency', full_name='core.api.SymbolInfo.position_currency', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market_name', full_name='core.api.SymbolInfo.market_name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1391,
)


_COMMSYMBOLINFO = _descriptor.Descriptor(
  name='CommSymbolInfo',
  full_name='core.api.CommSymbolInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.CommSymbolInfo.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1445,
)


_COMMSYMBOLINFOS = _descriptor.Descriptor(
  name='CommSymbolInfos',
  full_name='core.api.CommSymbolInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.CommSymbolInfos.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1500,
)


_STRATEGYTEMPLATE = _descriptor.Descriptor(
  name='StrategyTemplate',
  full_name='core.api.StrategyTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='core.api.StrategyTemplate.template_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='core.api.StrategyTemplate.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='core.api.StrategyTemplate.desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='core.api.StrategyTemplate.source', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_weight', full_name='core.api.StrategyTemplate.sort_weight', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_info', full_name='core.api.StrategyTemplate.param_info', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_mode', full_name='core.api.StrategyTemplate.param_mode', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stg_type', full_name='core.api.StrategyTemplate.stg_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1665,
)


_STRATEGYTEMPLATEITEM = _descriptor.Descriptor(
  name='StrategyTemplateItem',
  full_name='core.api.StrategyTemplateItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.StrategyTemplateItem.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1731,
)


_STRATEGYTEMPLATEITEMS = _descriptor.Descriptor(
  name='StrategyTemplateItems',
  full_name='core.api.StrategyTemplateItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.StrategyTemplateItems.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1798,
)

_CONNECTIONADDRESS_ADDRESSENTRY.containing_type = _CONNECTIONADDRESS
_CONNECTIONADDRESS.fields_by_name['address'].message_type = _CONNECTIONADDRESS_ADDRESSENTRY
_CONNECTIONSTATUS.fields_by_name['error'].message_type = _ERROR
_CONNECTIONSTATUS_STATE.containing_type = _CONNECTIONSTATUS
_LOG.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGS.fields_by_name['data'].message_type = _LOG
_HEARTBEAT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMBOLINFO.fields_by_name['listing_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMBOLINFO.fields_by_name['settle_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMSYMBOLINFO.fields_by_name['data'].message_type = _SYMBOLINFO
_COMMSYMBOLINFOS.fields_by_name['data'].message_type = _SYMBOLINFO
_STRATEGYTEMPLATEITEM.fields_by_name['data'].message_type = _STRATEGYTEMPLATE
_STRATEGYTEMPLATEITEMS.fields_by_name['data'].message_type = _STRATEGYTEMPLATE
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['ConnectionAddress'] = _CONNECTIONADDRESS
DESCRIPTOR.message_types_by_name['ConnectionStatus'] = _CONNECTIONSTATUS
DESCRIPTOR.message_types_by_name['Log'] = _LOG
DESCRIPTOR.message_types_by_name['Logs'] = _LOGS
DESCRIPTOR.message_types_by_name['Heartbeat'] = _HEARTBEAT
DESCRIPTOR.message_types_by_name['SymbolInfo'] = _SYMBOLINFO
DESCRIPTOR.message_types_by_name['CommSymbolInfo'] = _COMMSYMBOLINFO
DESCRIPTOR.message_types_by_name['CommSymbolInfos'] = _COMMSYMBOLINFOS
DESCRIPTOR.message_types_by_name['StrategyTemplate'] = _STRATEGYTEMPLATE
DESCRIPTOR.message_types_by_name['StrategyTemplateItem'] = _STRATEGYTEMPLATEITEM
DESCRIPTOR.message_types_by_name['StrategyTemplateItems'] = _STRATEGYTEMPLATEITEMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTY,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Property)
  ))
_sym_db.RegisterMessage(Property)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), dict(
  DESCRIPTOR = _FILTER,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Filter)
  ))
_sym_db.RegisterMessage(Filter)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Error)
  ))
_sym_db.RegisterMessage(Error)

ConnectionAddress = _reflection.GeneratedProtocolMessageType('ConnectionAddress', (_message.Message,), dict(

  AddressEntry = _reflection.GeneratedProtocolMessageType('AddressEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONNECTIONADDRESS_ADDRESSENTRY,
    __module__ = 'core.api.common_pb2'
    # @@protoc_insertion_point(class_scope:core.api.ConnectionAddress.AddressEntry)
    ))
  ,
  DESCRIPTOR = _CONNECTIONADDRESS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ConnectionAddress)
  ))
_sym_db.RegisterMessage(ConnectionAddress)
_sym_db.RegisterMessage(ConnectionAddress.AddressEntry)

ConnectionStatus = _reflection.GeneratedProtocolMessageType('ConnectionStatus', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSTATUS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ConnectionStatus)
  ))
_sym_db.RegisterMessage(ConnectionStatus)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), dict(
  DESCRIPTOR = _LOG,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Log)
  ))
_sym_db.RegisterMessage(Log)

Logs = _reflection.GeneratedProtocolMessageType('Logs', (_message.Message,), dict(
  DESCRIPTOR = _LOGS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Logs)
  ))
_sym_db.RegisterMessage(Logs)

Heartbeat = _reflection.GeneratedProtocolMessageType('Heartbeat', (_message.Message,), dict(
  DESCRIPTOR = _HEARTBEAT,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Heartbeat)
  ))
_sym_db.RegisterMessage(Heartbeat)

SymbolInfo = _reflection.GeneratedProtocolMessageType('SymbolInfo', (_message.Message,), dict(
  DESCRIPTOR = _SYMBOLINFO,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.SymbolInfo)
  ))
_sym_db.RegisterMessage(SymbolInfo)

CommSymbolInfo = _reflection.GeneratedProtocolMessageType('CommSymbolInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMMSYMBOLINFO,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.CommSymbolInfo)
  ))
_sym_db.RegisterMessage(CommSymbolInfo)

CommSymbolInfos = _reflection.GeneratedProtocolMessageType('CommSymbolInfos', (_message.Message,), dict(
  DESCRIPTOR = _COMMSYMBOLINFOS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.CommSymbolInfos)
  ))
_sym_db.RegisterMessage(CommSymbolInfos)

StrategyTemplate = _reflection.GeneratedProtocolMessageType('StrategyTemplate', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATE,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StrategyTemplate)
  ))
_sym_db.RegisterMessage(StrategyTemplate)

StrategyTemplateItem = _reflection.GeneratedProtocolMessageType('StrategyTemplateItem', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATEITEM,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StrategyTemplateItem)
  ))
_sym_db.RegisterMessage(StrategyTemplateItem)

StrategyTemplateItems = _reflection.GeneratedProtocolMessageType('StrategyTemplateItems', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATEITEMS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StrategyTemplateItems)
  ))
_sym_db.RegisterMessage(StrategyTemplateItems)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z(nextfin.com/nfplatform/core/api;core_api'))
_CONNECTIONADDRESS_ADDRESSENTRY.has_options = True
_CONNECTIONADDRESS_ADDRESSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_LOG.fields_by_name['created_at'].has_options = True
_LOG.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
_HEARTBEAT.fields_by_name['created_at'].has_options = True
_HEARTBEAT.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_SYMBOLINFO.fields_by_name['listing_date'].has_options = True
_SYMBOLINFO.fields_by_name['listing_date']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_SYMBOLINFO.fields_by_name['settle_date'].has_options = True
_SYMBOLINFO.fields_by_name['settle_date']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strategy/api/strategy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.api import common_pb2 as core_dot_api_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strategy/api/strategy.proto',
  package='strategy.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1bstrategy/api/strategy.proto\x12\x0cstrategy.api\x1a\x15\x63ore/api/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\x95\x04\n\x08Strategy\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05intro\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t\x12\r\n\x05stage\x18\x05 \x01(\x05\x12)\n\nparam_mode\x18\x08 \x01(\x05\x42\x15\xf2\xde\x1f\x11xorm:\"default(0)\"\x12\x12\n\nparam_info\x18\t \x01(\t\x12\x13\n\x0btemplate_id\x18\n \x01(\t\x12\'\n\x08stg_type\x18\x0b \x01(\x05\x42\x15\xf2\xde\x1f\x11xorm:\"default(0)\"\x12\x10\n\x08\x65xchange\x18\x0c \x01(\t\x12\r\n\x05\x66ront\x18\r \x01(\t\x12\x0c\n\x04rear\x18\x0e \x01(\t\x12\x0f\n\x07vol_sum\x18\x0f \x01(\t\x12\x13\n\x0bruntime_sum\x18\x10 \x01(\t\x12\x46\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\x12\x46\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"updated\"\"T\n\x05Stage\x12\x11\n\rStage_Unknown\x10\x00\x12\x12\n\x0eStage_Backtest\x10\x01\x12\x14\n\x10Stage_Simulation\x10\x02\x12\x0e\n\nStage_Live\x10\x03\"\xae\x01\n\x0bStrategyRds\x12\n\n\x02Id\x18\x01 \x01(\x03\x12\x13\n\x0bstrategy_id\x18\x02 \x01(\t\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12\x11\n\trds_value\x18\x04 \x01(\x01\x12\x10\n\x08rds_info\x18\x05 \x01(\t\x12\x46\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\"2\n\nStrategies\x12$\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x16.strategy.api.Strategy\"Q\n\x0eStrategyStatus\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12*\n\x06status\x18\x02 \x01(\x0b\x32\x1a.core.api.ConnectionStatus\">\n\x10StrategyStatuses\x12*\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1c.strategy.api.StrategyStatus\"I\n\x0bStopCommand\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\x05\x12\x15\n\rreason_detail\x18\x03 \x01(\t\"\x8e\x01\n\x0cStartCommand\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x18\n\x10interpreter_path\x18\x05 \x01(\t\x12\x1d\n\x15interpreter_venv_path\x18\x06 \x01(\t\"9\n\rStartCommands\x12(\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1a.strategy.api.StartCommandB2Z0nextfin.com/nfplatform/strategy/api;strategy_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])



_STRATEGY_STAGE = _descriptor.EnumDescriptor(
  name='Stage',
  full_name='strategy.api.Strategy.Stage',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Stage_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stage_Backtest', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stage_Simulation', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stage_Live', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=573,
  serialized_end=657,
)
_sym_db.RegisterEnumDescriptor(_STRATEGY_STAGE)


_STRATEGY = _descriptor.Descriptor(
  name='Strategy',
  full_name='strategy.api.Strategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.Strategy.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='strategy.api.Strategy.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intro', full_name='strategy.api.Strategy.intro', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='strategy.api.Strategy.language', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='strategy.api.Strategy.stage', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_mode', full_name='strategy.api.Strategy.param_mode', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))),
    _descriptor.FieldDescriptor(
      name='param_info', full_name='strategy.api.Strategy.param_info', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='template_id', full_name='strategy.api.Strategy.template_id', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stg_type', full_name='strategy.api.Strategy.stg_type', index=8,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.api.Strategy.exchange', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.api.Strategy.front', index=10,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.api.Strategy.rear', index=11,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vol_sum', full_name='strategy.api.Strategy.vol_sum', index=12,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime_sum', full_name='strategy.api.Strategy.runtime_sum', index=13,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='strategy.api.Strategy.created_at', index=14,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='strategy.api.Strategy.updated_at', index=15,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"updated\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STRATEGY_STAGE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=657,
)


_STRATEGYRDS = _descriptor.Descriptor(
  name='StrategyRds',
  full_name='strategy.api.StrategyRds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Id', full_name='strategy.api.StrategyRds.Id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StrategyRds.strategy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='strategy.api.StrategyRds.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rds_value', full_name='strategy.api.StrategyRds.rds_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rds_info', full_name='strategy.api.StrategyRds.rds_info', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='strategy.api.StrategyRds.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=834,
)


_STRATEGIES = _descriptor.Descriptor(
  name='Strategies',
  full_name='strategy.api.Strategies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.Strategies.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=886,
)


_STRATEGYSTATUS = _descriptor.Descriptor(
  name='StrategyStatus',
  full_name='strategy.api.StrategyStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StrategyStatus.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='strategy.api.StrategyStatus.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=969,
)


_STRATEGYSTATUSES = _descriptor.Descriptor(
  name='StrategyStatuses',
  full_name='strategy.api.StrategyStatuses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.StrategyStatuses.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1033,
)


_STOPCOMMAND = _descriptor.Descriptor(
  name='StopCommand',
  full_name='strategy.api.StopCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StopCommand.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='strategy.api.StopCommand.reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason_detail', full_name='strategy.api.StopCommand.reason_detail', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1108,
)


_STARTCOMMAND = _descriptor.Descriptor(
  name='StartCommand',
  full_name='strategy.api.StartCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StartCommand.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='strategy.api.StartCommand.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directory', full_name='strategy.api.StartCommand.directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='strategy.api.StartCommand.path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpreter_path', full_name='strategy.api.StartCommand.interpreter_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpreter_venv_path', full_name='strategy.api.StartCommand.interpreter_venv_path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1253,
)


_STARTCOMMANDS = _descriptor.Descriptor(
  name='StartCommands',
  full_name='strategy.api.StartCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.StartCommands.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1312,
)

_STRATEGY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STRATEGY.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STRATEGY_STAGE.containing_type = _STRATEGY
_STRATEGYRDS.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STRATEGIES.fields_by_name['data'].message_type = _STRATEGY
_STRATEGYSTATUS.fields_by_name['status'].message_type = core_dot_api_dot_common__pb2._CONNECTIONSTATUS
_STRATEGYSTATUSES.fields_by_name['data'].message_type = _STRATEGYSTATUS
_STARTCOMMANDS.fields_by_name['data'].message_type = _STARTCOMMAND
DESCRIPTOR.message_types_by_name['Strategy'] = _STRATEGY
DESCRIPTOR.message_types_by_name['StrategyRds'] = _STRATEGYRDS
DESCRIPTOR.message_types_by_name['Strategies'] = _STRATEGIES
DESCRIPTOR.message_types_by_name['StrategyStatus'] = _STRATEGYSTATUS
DESCRIPTOR.message_types_by_name['StrategyStatuses'] = _STRATEGYSTATUSES
DESCRIPTOR.message_types_by_name['StopCommand'] = _STOPCOMMAND
DESCRIPTOR.message_types_by_name['StartCommand'] = _STARTCOMMAND
DESCRIPTOR.message_types_by_name['StartCommands'] = _STARTCOMMANDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Strategy = _reflection.GeneratedProtocolMessageType('Strategy', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGY,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.Strategy)
  ))
_sym_db.RegisterMessage(Strategy)

StrategyRds = _reflection.GeneratedProtocolMessageType('StrategyRds', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYRDS,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategyRds)
  ))
_sym_db.RegisterMessage(StrategyRds)

Strategies = _reflection.GeneratedProtocolMessageType('Strategies', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGIES,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.Strategies)
  ))
_sym_db.RegisterMessage(Strategies)

StrategyStatus = _reflection.GeneratedProtocolMessageType('StrategyStatus', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYSTATUS,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategyStatus)
  ))
_sym_db.RegisterMessage(StrategyStatus)

StrategyStatuses = _reflection.GeneratedProtocolMessageType('StrategyStatuses', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYSTATUSES,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategyStatuses)
  ))
_sym_db.RegisterMessage(StrategyStatuses)

StopCommand = _reflection.GeneratedProtocolMessageType('StopCommand', (_message.Message,), dict(
  DESCRIPTOR = _STOPCOMMAND,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StopCommand)
  ))
_sym_db.RegisterMessage(StopCommand)

StartCommand = _reflection.GeneratedProtocolMessageType('StartCommand', (_message.Message,), dict(
  DESCRIPTOR = _STARTCOMMAND,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StartCommand)
  ))
_sym_db.RegisterMessage(StartCommand)

StartCommands = _reflection.GeneratedProtocolMessageType('StartCommands', (_message.Message,), dict(
  DESCRIPTOR = _STARTCOMMANDS,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StartCommands)
  ))
_sym_db.RegisterMessage(StartCommands)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z0nextfin.com/nfplatform/strategy/api;strategy_api'))
_STRATEGY.fields_by_name['param_mode'].has_options = True
_STRATEGY.fields_by_name['param_mode']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))
_STRATEGY.fields_by_name['stg_type'].has_options = True
_STRATEGY.fields_by_name['stg_type']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))
_STRATEGY.fields_by_name['created_at'].has_options = True
_STRATEGY.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
_STRATEGY.fields_by_name['updated_at'].has_options = True
_STRATEGY.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"updated\"'))
_STRATEGYRDS.fields_by_name['created_at'].has_options = True
_STRATEGYRDS.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
# @@protoc_insertion_point(module_scope)



# coding=utf-8
from __future__ import unicode_literals, print_function, absolute_import
import six

from nf.api import PositionSide_Long, PositionSide_Short


# 账户
class Account(object):
    def __init__(self, id, name, cash, positions):
        self.id = id
        self.name = name
        self.cash = cash
        self.inside_positions = positions

    def match(self, name):
        if self.name == name:
            return True

        if self.id == name:
            return True

    def positions(self, symbol='', side=None):
        # 默认返回全部
        if not symbol and not side:
            info = list(six.itervalues(self.inside_positions))
            return info

        # 只有side 返回空仓和多仓
        if not symbol and side:
            info = list(six.itervalues(self.inside_positions))
            return [i for i in info if i.get('side') == side]

        # 只有symbol 没有side 返回固定symbol的空仓和多仓
        if symbol and not side:
            long_key = '{}.{}'.format(symbol, PositionSide_Long)
            long_info = self.inside_positions.get(long_key)

            short_key = '{}.{}'.format(symbol, PositionSide_Short)
            short_info = self.inside_positions.get(short_key)

            result = []
            if long_info:
                result.append(long_info)
            if short_info:
                result.append(short_info)
            return result

        # 返回指定仓位
        key = '{}.{}'.format(symbol, side)
        info = self.inside_positions.get(key)
        if not info:
            return []

        return [info]

    def position(self, symbol, side):
        key = '{}.{}'.format(symbol, side)
        return self.inside_positions.get(key)



# coding=utf-8
from __future__ import print_function

import glob
import os
import shutil
from distutils.core import setup
from distutils.extension import Extension
from distutils.util import get_platform

from Cython.Distutils import build_ext

remove_files = ['c_sdk.cpp', 'c_sdk.pyd', 'c_sdk.cp36-win32.pyd', 'c_sdk.cp36-win_amd64.pyd', 'libgm3-c.so',
                'gmsdk-c.dll']
for f in remove_files:
    if os.path.exists(f):
        os.remove(f)

platform = get_platform()
dlllibdir = './lib/{}'.format(platform)
ext_modules = [Extension("c_sdk",
                     ["c_sdk.pyx"],
                     language='c++',
                     include_dirs=['./include'],
                     library_dirs=[dlllibdir],
                     libraries=["nf-sdk-c"],
                     extra_compile_args=['/MT']
                     )]

setup(
  name='c_sdk',
  cmdclass={'build_ext': build_ext},
  ext_modules=ext_modules,
)

dllext = '*.dll'
if platform.startswith('linux'):
    dllext = '*.so'
dllfiles = glob.iglob(os.path.join('./lib/{}/'.format(platform), dllext))
for f in dllfiles:
    if os.path.isfile(f):
        shutil.copy2(f, './{}'.format(os.path.split(f)[1]))



# coding=utf8
from __future__ import print_function, absolute_import, unicode_literals

SecurityType_Physical = 0   # 现货
SecurityType_Future = 1     # 期货

ExecType_Unknown = 0
ExecType_Failed = 1             # 报送失败
ExecType_New = 2                # 已报送
ExecType_PartiallyFilled = 3    # 部分成交
ExecType_PartiallyCanceled = 4  # 部分成交撤销
ExecType_Filled = 5             # 已完成
ExecType_Canceled = 6           # 已撤销
ExecType_Expired = 7            # 过期
ExecType_Rejected = 8           # 已拒绝
ExecType_PendingNew = 10        # 待报
ExecType_CancelRejected = 19    # 撤单被拒绝

OrderStatus_Unknown = 0
OrderStatus_Failed = 1              # 报送失败
OrderStatus_New = 2                 # 已报送
OrderStatus_PartiallyFilled = 3     # 部分成交
OrderStatus_PartiallyCanceled = 4   # 部分成交撤销
OrderStatus_Filled = 5              # 已完成
OrderStatus_Canceled = 6            # 已撤销
OrderStatus_Expired = 7             # 过期
OrderStatus_Rejected = 8            # 已拒绝
OrderStatus_PendingNew = 10         # 待报

OrderRejectReason_Unknown = 0                           # 未知原因
OrderRejectReason_RiskRuleCheckFailed = 1               # 不符合风控规则
OrderRejectReason_NoEnoughCash = 2                      # 资金不足
OrderRejectReason_NoEnoughPosition = 3                  # 仓位不足
OrderRejectReason_IllegalAccountId = 4                  # 非法账户ID
OrderRejectReason_IllegalStrategyId = 5                 # 非法策略ID
OrderRejectReason_IllegalSymbol = 6                     # 非法交易代码
OrderRejectReason_IllegalVolume = 7                     # 非法委托量
OrderRejectReason_IllegalPrice = 8                      # 非法委托价
OrderRejectReason_AccountDisabled = 10                  # 交易账号被禁止交易
OrderRejectReason_AccountDisconnected = 11              # 交易账号未连接
OrderRejectReason_AccountLoggedout = 12                 # 交易账号未登录
OrderRejectReason_NotInTradingSession = 13              # 非交易时段
OrderRejectReason_OrderTypeNotSupported = 14            # 委托类型不支持
OrderRejectReason_Throttle = 15                         # 流控限制
OrderRejectReason_SymbolSuspended = 16                  # 交易代码停牌
OrderRejectReason_Internal = 999                        # 内部错误
CancelOrderRejectReason_OrderFinalized = 101            # 委托已完成
CancelOrderRejectReason_UnknownOrder = 102              # 未知委托
CancelOrderRejectReason_BrokerOption = 103              # 柜台设置
CancelOrderRejectReason_AlreadyInPendingCancel = 104    # 委托撤销中

OrderSide_Unknown = 0
OrderSide_Buy = 1                   # 买入
OrderSide_Sell = 2                  # 卖出
OrderSide_Buy_Open = 3              # 买入开仓
OrderSide_Buy_Close = 4             # 买入平仓
OrderSide_Sell_Open = 5             # 卖出开仓
OrderSide_Sell_Close = 6            # 卖出平仓
OrderSide_Sell_Liquidation = 7      # 强平卖出，以下4种交易所下单返回
OrderSide_Sell_Reduce = 8           # 减仓卖出
OrderSide_Buy_Liquidation = 9       # 强平买入
OrderSide_Buy_Reduce = 10           # 减仓买入

OrderType_Unknown = 0
OrderType_Limit = 1         # 限价委托
OrderType_Market = 2        # 市价委托
OrderType_StopMarket = 3    # 市价止损委托
OrderType_StopLimit = 4     # 限价止损委托
OrderType_ProfitMarket = 5  # 市价止盈委托
OrderType_ProfitLimit = 6   # 限价止盈委托

OrderDuration_Unknown = 0
OrderDuration_FAK = 1  # 即时成交剩余撤销(fill and kill)
OrderDuration_FOK = 2  # 即时全额成交或撤销(fill or kill)
OrderDuration_GFD = 3  # 当日有效(good for day)
OrderDuration_GFS = 4  # 本节有效(good for section)
OrderDuration_GTD = 5  # 指定日期前有效(goodltilldate)
OrderDuration_GTC = 6  # 撤销前有效(goodtillcancel)
OrderDuration_GFA = 7  # 集合竞价前有效(good for auction)

OrderQualifier_Unknown = 0
OrderQualifier_BOC = 1  # 对方最优价格(best of counterparty)
OrderQualifier_BOP = 2  # 己方最优价格(best of party)
OrderQualifier_B5TC = 3  # 最优五档剩余撤销(best 5 then cancel)
OrderQualifier_B5TL = 4  # 最优五档剩余转限价(best 5 then limit)

OrderStyle_Unknown = 0
OrderStyle_Volume = 1
OrderStyle_Value = 2

PositionSide_Unknown = 0
PositionSide_Long = 1  # 多方向
PositionSide_Short = 2  # 空方向

PositionEffect_Unknown = 0
PositionEffect_Open = 1  # 开仓
PositionEffect_Close = 2  # 平仓, 具体语义取决于对应的交易所
PositionEffect_CloseToday = 3  # 平今仓
PositionEffect_CloseYesterday = 4  # 平昨仓

CashPositionChangeReason_Unknown = 0
CashPositionChangeReason_Trade = 1  # 交易
CashPositionChangeReason_Inout = 2  # 出入金 / 出入持仓

MODE_UNKNOWN = 0
MODE_LIVE = 1
MODE_BACKTEST = 2

ADJUST_NONE = 0
ADJUST_PREV = 1
ADJUST_POST = 2


ExecInstType_PostOnly = 0  # 被动委托 Valid options: ParticipateDoNotInitiate, AllOrNone, MarkPrice, IndexPrice, LastPrice, Close, ReduceOnly, Fixed. 'AllOrNone' instruction requires displayQty to be 0. 'MarkPrice', 'IndexPrice' or 'LastPrice' instruction valid for 'Stop', 'StopLimit', 'MarketIfTouched', and 'LimitIfTouched' orders.
ExecInstType_MarkPrice = 1  # 在止损/盈单中触发价使用标记价格MarkPrice 此3个价格不可多选
ExecInstType_IndexPrice = 2  # 在止损/盈单中触发价使用指数价格（bitmex指数）IndexPrice
ExecInstType_LastPrice = 3  # 在止损/盈单中触发价使用最新的合约价格LastPrice
ExecInstType_ReduceOnly = 4  # 只减仓，只减少持有的仓位，而不允许另开当前持仓反向的仓位；不影响其他活跃但没有执行的订单，打算减仓建议使用ReduceOnly



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strategy/api/strategy.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.api import common_pb2 as core_dot_api_dot_common__pb2
from strategy.api import strategy_pb2 as strategy_dot_api_dot_strategy__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strategy/api/strategy.service.proto',
  package='strategy.api',
  syntax='proto3',
  serialized_pb=_b('\n#strategy/api/strategy.service.proto\x12\x0cstrategy.api\x1a\x15\x63ore/api/common.proto\x1a\x1bstrategy/api/strategy.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"Y\n\x0eSetAccountsReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\r\n\x05stage\x18\x02 \x01(\x05\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x03 \x03(\t\x12\x0e\n\x06market\x18\x04 \x01(\t\"4\n\x0eGetAccountsReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\r\n\x05stage\x18\x02 \x01(\x05\"%\n\x0eGetAccountsRsp\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\t\"/\n\x19GetStrategiesToAccountReq\x12\x12\n\naccount_id\x18\x01 \x01(\t\"J\n\x10GetStrategiesReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x14\n\x0cstrategy_ids\x18\x02 \x03(\t\"]\n\x17GetStrategiesOfStageReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x0e\n\x06stages\x18\x02 \x03(\x05\x12\x10\n\x08stg_type\x18\x03 \x01(\x05\"(\n\x10\x44\x65lStrategiesReq\x12\x14\n\x0cstrategy_ids\x18\x01 \x03(\t\"M\n\x13GetStartCommandsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x14\n\x0cstrategy_ids\x18\x02 \x03(\t\"P\n\x16GetStrategyStatusesReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x14\n\x0cstrategy_ids\x18\x02 \x03(\t\"K\n\x12GetStrategyLogsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x13\n\x0bstrategy_id\x18\x02 \x01(\t\"5\n\x0eStrategySignal\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0e\n\x06signal\x18\x02 \x01(\x05\"\x82\x01\n\x12\x41\x64\x64\x42indStrategyReq\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\t\x12(\n\x08strategy\x18\x02 \x01(\x0b\x32\x16.strategy.api.Strategy\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\r\n\x05\x66ront\x18\x04 \x01(\t\x12\x0c\n\x04rear\x18\x05 \x01(\t\"(\n\x11GetstrategyRdsReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\"<\n\x11GetstrategyRdsRsp\x12\'\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.strategy.api.StrategyRds2\x81\x11\n\x0fStrategyService\x12X\n\x0b\x41\x64\x64Strategy\x12\x16.strategy.api.Strategy\x1a\x16.strategy.api.Strategy\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v3/strategies:\x01*\x12i\n\x0f\x41\x64\x64\x42indStrategy\x12 .strategy.api.AddBindStrategyReq\x1a\x16.strategy.api.Strategy\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/strategies-ab:\x01*\x12m\n\tEditParam\x12\x16.strategy.api.Strategy\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/v3/strategieparam/{strategy_id}/edit:\x01*\x12\x61\n\rGetStrategies\x12\x1e.strategy.api.GetStrategiesReq\x1a\x18.strategy.api.Strategies\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v3/strategies\x12x\n\x14GetStrategiesOfStage\x12%.strategy.api.GetStrategiesOfStageReq\x1a\x18.strategy.api.Strategies\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v3/strategies-of-stage\x12\x66\n\x0bSetStrategy\x12\x16.strategy.api.Strategy\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v3/strategies/{strategy_id}:\x01*\x12y\n\x11SetStrategySignal\x12\x1c.strategy.api.StrategySignal\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/v3/strategies/{strategy_id}/signal:\x01*\x12i\n\rDelStrategies\x12\x1e.strategy.api.DelStrategiesReq\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/strategies-delete:\x01*\x12u\n\x0bSetAccounts\x12\x1c.strategy.api.SetAccountsReq\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/v3/strategies/{strategy_id}/accounts:\x01*\x12x\n\x0bGetAccounts\x12\x1c.strategy.api.GetAccountsReq\x1a\x1c.strategy.api.GetAccountsRsp\"-\x82\xd3\xe4\x93\x02\'\x12%/v3/strategies/{strategy_id}/accounts\x12\x8b\x01\n\x16GetStrategiesToAccount\x12\'.strategy.api.GetStrategiesToAccountReq\x1a\x18.strategy.api.Strategies\".\x82\xd3\xe4\x93\x02(\x12&/v3/strategies-to-account/{account_id}\x12z\n\x13GetStrategyStatuses\x12$.strategy.api.GetStrategyStatusesReq\x1a\x1e.strategy.api.StrategyStatuses\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v3/strategy-statuses\x12o\n\x13SetStrategyStatuses\x12\x1e.strategy.api.StrategyStatuses\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/strategy-statuses:\x01*\x12v\n\x0cStopStrategy\x12\x19.strategy.api.StopCommand\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/v3/strategy-commands/{strategy_id}/stop:\x01*\x12q\n\x10GetStartCommands\x12!.strategy.api.GetStartCommandsReq\x1a\x1b.strategy.api.StartCommands\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v3/strategy-commands\x12u\n\x0fSetStartCommand\x12\x1a.strategy.api.StartCommand\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\x1a#/v3/strategy-commands/{strategy_id}:\x01*\x12W\n\x0f\x41\x64\x64StrategyLogs\x12\x0e.core.api.Logs\x1a\x16.google.protobuf.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/strategy-logs:\x01*\x12l\n\x0fGetStrategyLogs\x12 .strategy.api.GetStrategyLogsReq\x1a\x0e.core.api.Logs\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v3/strategy-logs/{strategy_id}\x12z\n\x0eGetstrategyRds\x12\x1f.strategy.api.GetstrategyRdsReq\x1a\x1f.strategy.api.GetstrategyRdsRsp\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v3/strategy-rds/{strategy_id}B2Z0nextfin.com/nfplatform/strategy/api;strategy_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,strategy_dot_api_dot_strategy__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_SETACCOUNTSREQ = _descriptor.Descriptor(
  name='SetAccountsReq',
  full_name='strategy.api.SetAccountsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.SetAccountsReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='strategy.api.SetAccountsReq.stage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='strategy.api.SetAccountsReq.account_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market', full_name='strategy.api.SetAccountsReq.market', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=253,
)


_GETACCOUNTSREQ = _descriptor.Descriptor(
  name='GetAccountsReq',
  full_name='strategy.api.GetAccountsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.GetAccountsReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='strategy.api.GetAccountsReq.stage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=255,
  serialized_end=307,
)


_GETACCOUNTSRSP = _descriptor.Descriptor(
  name='GetAccountsRsp',
  full_name='strategy.api.GetAccountsRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='strategy.api.GetAccountsRsp.account_ids', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=346,
)


_GETSTRATEGIESTOACCOUNTREQ = _descriptor.Descriptor(
  name='GetStrategiesToAccountReq',
  full_name='strategy.api.GetStrategiesToAccountReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='strategy.api.GetStrategiesToAccountReq.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=395,
)


_GETSTRATEGIESREQ = _descriptor.Descriptor(
  name='GetStrategiesReq',
  full_name='strategy.api.GetStrategiesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategiesReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.GetStrategiesReq.strategy_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=471,
)


_GETSTRATEGIESOFSTAGEREQ = _descriptor.Descriptor(
  name='GetStrategiesOfStageReq',
  full_name='strategy.api.GetStrategiesOfStageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategiesOfStageReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stages', full_name='strategy.api.GetStrategiesOfStageReq.stages', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stg_type', full_name='strategy.api.GetStrategiesOfStageReq.stg_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=566,
)


_DELSTRATEGIESREQ = _descriptor.Descriptor(
  name='DelStrategiesReq',
  full_name='strategy.api.DelStrategiesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.DelStrategiesReq.strategy_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=608,
)


_GETSTARTCOMMANDSREQ = _descriptor.Descriptor(
  name='GetStartCommandsReq',
  full_name='strategy.api.GetStartCommandsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStartCommandsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.GetStartCommandsReq.strategy_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=687,
)


_GETSTRATEGYSTATUSESREQ = _descriptor.Descriptor(
  name='GetStrategyStatusesReq',
  full_name='strategy.api.GetStrategyStatusesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategyStatusesReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.GetStrategyStatusesReq.strategy_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=769,
)


_GETSTRATEGYLOGSREQ = _descriptor.Descriptor(
  name='GetStrategyLogsReq',
  full_name='strategy.api.GetStrategyLogsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategyLogsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.GetStrategyLogsReq.strategy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=846,
)


_STRATEGYSIGNAL = _descriptor.Descriptor(
  name='StrategySignal',
  full_name='strategy.api.StrategySignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StrategySignal.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='strategy.api.StrategySignal.signal', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=901,
)


_ADDBINDSTRATEGYREQ = _descriptor.Descriptor(
  name='AddBindStrategyReq',
  full_name='strategy.api.AddBindStrategyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='strategy.api.AddBindStrategyReq.account_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='strategy.api.AddBindStrategyReq.strategy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.api.AddBindStrategyReq.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.api.AddBindStrategyReq.front', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.api.AddBindStrategyReq.rear', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=1034,
)


_GETSTRATEGYRDSREQ = _descriptor.Descriptor(
  name='GetstrategyRdsReq',
  full_name='strategy.api.GetstrategyRdsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.GetstrategyRdsReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1076,
)


_GETSTRATEGYRDSRSP = _descriptor.Descriptor(
  name='GetstrategyRdsRsp',
  full_name='strategy.api.GetstrategyRdsRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.GetstrategyRdsRsp.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1138,
)

_GETSTRATEGIESREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTRATEGIESOFSTAGEREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTARTCOMMANDSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTRATEGYSTATUSESREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTRATEGYLOGSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_ADDBINDSTRATEGYREQ.fields_by_name['strategy'].message_type = strategy_dot_api_dot_strategy__pb2._STRATEGY
_GETSTRATEGYRDSRSP.fields_by_name['data'].message_type = strategy_dot_api_dot_strategy__pb2._STRATEGYRDS
DESCRIPTOR.message_types_by_name['SetAccountsReq'] = _SETACCOUNTSREQ
DESCRIPTOR.message_types_by_name['GetAccountsReq'] = _GETACCOUNTSREQ
DESCRIPTOR.message_types_by_name['GetAccountsRsp'] = _GETACCOUNTSRSP
DESCRIPTOR.message_types_by_name['GetStrategiesToAccountReq'] = _GETSTRATEGIESTOACCOUNTREQ
DESCRIPTOR.message_types_by_name['GetStrategiesReq'] = _GETSTRATEGIESREQ
DESCRIPTOR.message_types_by_name['GetStrategiesOfStageReq'] = _GETSTRATEGIESOFSTAGEREQ
DESCRIPTOR.message_types_by_name['DelStrategiesReq'] = _DELSTRATEGIESREQ
DESCRIPTOR.message_types_by_name['GetStartCommandsReq'] = _GETSTARTCOMMANDSREQ
DESCRIPTOR.message_types_by_name['GetStrategyStatusesReq'] = _GETSTRATEGYSTATUSESREQ
DESCRIPTOR.message_types_by_name['GetStrategyLogsReq'] = _GETSTRATEGYLOGSREQ
DESCRIPTOR.message_types_by_name['StrategySignal'] = _STRATEGYSIGNAL
DESCRIPTOR.message_types_by_name['AddBindStrategyReq'] = _ADDBINDSTRATEGYREQ
DESCRIPTOR.message_types_by_name['GetstrategyRdsReq'] = _GETSTRATEGYRDSREQ
DESCRIPTOR.message_types_by_name['GetstrategyRdsRsp'] = _GETSTRATEGYRDSRSP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetAccountsReq = _reflection.GeneratedProtocolMessageType('SetAccountsReq', (_message.Message,), dict(
  DESCRIPTOR = _SETACCOUNTSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.SetAccountsReq)
  ))
_sym_db.RegisterMessage(SetAccountsReq)

GetAccountsReq = _reflection.GeneratedProtocolMessageType('GetAccountsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetAccountsReq)
  ))
_sym_db.RegisterMessage(GetAccountsReq)

GetAccountsRsp = _reflection.GeneratedProtocolMessageType('GetAccountsRsp', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSRSP,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetAccountsRsp)
  ))
_sym_db.RegisterMessage(GetAccountsRsp)

GetStrategiesToAccountReq = _reflection.GeneratedProtocolMessageType('GetStrategiesToAccountReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGIESTOACCOUNTREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategiesToAccountReq)
  ))
_sym_db.RegisterMessage(GetStrategiesToAccountReq)

GetStrategiesReq = _reflection.GeneratedProtocolMessageType('GetStrategiesReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGIESREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategiesReq)
  ))
_sym_db.RegisterMessage(GetStrategiesReq)

GetStrategiesOfStageReq = _reflection.GeneratedProtocolMessageType('GetStrategiesOfStageReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGIESOFSTAGEREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategiesOfStageReq)
  ))
_sym_db.RegisterMessage(GetStrategiesOfStageReq)

DelStrategiesReq = _reflection.GeneratedProtocolMessageType('DelStrategiesReq', (_message.Message,), dict(
  DESCRIPTOR = _DELSTRATEGIESREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.DelStrategiesReq)
  ))
_sym_db.RegisterMessage(DelStrategiesReq)

GetStartCommandsReq = _reflection.GeneratedProtocolMessageType('GetStartCommandsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTARTCOMMANDSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStartCommandsReq)
  ))
_sym_db.RegisterMessage(GetStartCommandsReq)

GetStrategyStatusesReq = _reflection.GeneratedProtocolMessageType('GetStrategyStatusesReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYSTATUSESREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategyStatusesReq)
  ))
_sym_db.RegisterMessage(GetStrategyStatusesReq)

GetStrategyLogsReq = _reflection.GeneratedProtocolMessageType('GetStrategyLogsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYLOGSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategyLogsReq)
  ))
_sym_db.RegisterMessage(GetStrategyLogsReq)

StrategySignal = _reflection.GeneratedProtocolMessageType('StrategySignal', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYSIGNAL,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategySignal)
  ))
_sym_db.RegisterMessage(StrategySignal)

AddBindStrategyReq = _reflection.GeneratedProtocolMessageType('AddBindStrategyReq', (_message.Message,), dict(
  DESCRIPTOR = _ADDBINDSTRATEGYREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.AddBindStrategyReq)
  ))
_sym_db.RegisterMessage(AddBindStrategyReq)

GetstrategyRdsReq = _reflection.GeneratedProtocolMessageType('GetstrategyRdsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYRDSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetstrategyRdsReq)
  ))
_sym_db.RegisterMessage(GetstrategyRdsReq)

GetstrategyRdsRsp = _reflection.GeneratedProtocolMessageType('GetstrategyRdsRsp', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYRDSRSP,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetstrategyRdsRsp)
  ))
_sym_db.RegisterMessage(GetstrategyRdsRsp)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z0nextfin.com/nfplatform/strategy/api;strategy_api'))

_STRATEGYSERVICE = _descriptor.ServiceDescriptor(
  name='StrategyService',
  full_name='strategy.api.StrategyService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1141,
  serialized_end=3318,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddStrategy',
    full_name='strategy.api.StrategyService.AddStrategy',
    index=0,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\023\"\016/v3/strategies:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='AddBindStrategy',
    full_name='strategy.api.StrategyService.AddBindStrategy',
    index=1,
    containing_service=None,
    input_type=_ADDBINDSTRATEGYREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\026\"\021/v3/strategies-ab:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='EditParam',
    full_name='strategy.api.StrategyService.EditParam',
    index=2,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002*\"%/v3/strategieparam/{strategy_id}/edit:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategies',
    full_name='strategy.api.StrategyService.GetStrategies',
    index=3,
    containing_service=None,
    input_type=_GETSTRATEGIESREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\020\022\016/v3/strategies')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategiesOfStage',
    full_name='strategy.api.StrategyService.GetStrategiesOfStage',
    index=4,
    containing_service=None,
    input_type=_GETSTRATEGIESOFSTAGEREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\031\022\027/v3/strategies-of-stage')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStrategy',
    full_name='strategy.api.StrategyService.SetStrategy',
    index=5,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002!\"\034/v3/strategies/{strategy_id}:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStrategySignal',
    full_name='strategy.api.StrategyService.SetStrategySignal',
    index=6,
    containing_service=None,
    input_type=_STRATEGYSIGNAL,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\"#/v3/strategies/{strategy_id}/signal:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='DelStrategies',
    full_name='strategy.api.StrategyService.DelStrategies',
    index=7,
    containing_service=None,
    input_type=_DELSTRATEGIESREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/v3/strategies-delete:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='SetAccounts',
    full_name='strategy.api.StrategyService.SetAccounts',
    index=8,
    containing_service=None,
    input_type=_SETACCOUNTSREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002*\"%/v3/strategies/{strategy_id}/accounts:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAccounts',
    full_name='strategy.api.StrategyService.GetAccounts',
    index=9,
    containing_service=None,
    input_type=_GETACCOUNTSREQ,
    output_type=_GETACCOUNTSRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\022%/v3/strategies/{strategy_id}/accounts')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategiesToAccount',
    full_name='strategy.api.StrategyService.GetStrategiesToAccount',
    index=10,
    containing_service=None,
    input_type=_GETSTRATEGIESTOACCOUNTREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\022&/v3/strategies-to-account/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyStatuses',
    full_name='strategy.api.StrategyService.GetStrategyStatuses',
    index=11,
    containing_service=None,
    input_type=_GETSTRATEGYSTATUSESREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGYSTATUSES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\022\025/v3/strategy-statuses')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStrategyStatuses',
    full_name='strategy.api.StrategyService.SetStrategyStatuses',
    index=12,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGYSTATUSES,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/v3/strategy-statuses:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='StopStrategy',
    full_name='strategy.api.StrategyService.StopStrategy',
    index=13,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STOPCOMMAND,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002-\"(/v3/strategy-commands/{strategy_id}/stop:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStartCommands',
    full_name='strategy.api.StrategyService.GetStartCommands',
    index=14,
    containing_service=None,
    input_type=_GETSTARTCOMMANDSREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STARTCOMMANDS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\022\025/v3/strategy-commands')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStartCommand',
    full_name='strategy.api.StrategyService.SetStartCommand',
    index=15,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STARTCOMMAND,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\032#/v3/strategy-commands/{strategy_id}:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='AddStrategyLogs',
    full_name='strategy.api.StrategyService.AddStrategyLogs',
    index=16,
    containing_service=None,
    input_type=core_dot_api_dot_common__pb2._LOGS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\026\"\021/v3/strategy-logs:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyLogs',
    full_name='strategy.api.StrategyService.GetStrategyLogs',
    index=17,
    containing_service=None,
    input_type=_GETSTRATEGYLOGSREQ,
    output_type=core_dot_api_dot_common__pb2._LOGS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002!\022\037/v3/strategy-logs/{strategy_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetstrategyRds',
    full_name='strategy.api.StrategyService.GetstrategyRds',
    index=18,
    containing_service=None,
    input_type=_GETSTRATEGYRDSREQ,
    output_type=_GETSTRATEGYRDSRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002 \022\036/v3/strategy-rds/{strategy_id}')),
  ),
])
_sym_db.RegisterServiceDescriptor(_STRATEGYSERVICE)

DESCRIPTOR.services_by_name['StrategyService'] = _STRATEGYSERVICE

# @@protoc_insertion_point(module_scope)



# coding=utf-8
from __future__ import unicode_literals, print_function, absolute_import

import pandas as pd

from nf.csdk.c_sdk import py_nfi_get_trades
from datetime import date, datetime
from nf.constant import CSDK_OPERATE_SUCCESS
from nf.pb.data.api.data_pb2 import Trades
from nf.pb_to_dict import protobuf_to_dict, dict_to_protobuf

from nf import utils
from nf.constant import DATA_TYPE_TICK

from nf.utils import load_to_datetime_str, protomessage2dict


pd.set_option('precision', 4)


def get_trades(symbol, end_time=None, count=50, df=False):
    if not symbol or len(symbol) <= 0:
        return []

    if count > 1000:
        count = 1000

    if not end_time:
        end_time = datetime.now()

    if isinstance(end_time, (date, datetime)):
        end_time = load_to_datetime_str(end_time)

    status, result = py_nfi_get_trades(symbol, end_time, count)

    if not status == CSDK_OPERATE_SUCCESS:
        print('unable to get trade data. error code: ', status)
        return []

    trades = Trades()
    trades.ParseFromString(result)

    tlist = [protobuf_to_dict(trade) for trade in trades.data]

    trade_list = []

    for trade in tlist:
        nt = {}

        nt['symbol'] = symbol
        nt['amount'] = trade['volume']
        nt['price'] = trade['price']
        nt['side'] = trade['side']
        nt['time'] = trade['created_at']

        trade_list.append(nt)
    if not df:
        return trade_list
    else:
        data = pd.DataFrame(trade_list)

        return data






